==> benno-web-2.4.6.tgz: srv/benno/bennoweb/htdocs/view/printMail.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

$default_contenttype = $App->getConfig('DEFAULT_CONTENTYPE','text/plain');
try {
    $body_content = $EMail->getBody($default_contenttype);
    $body_type = $default_contenttype;
}
catch (Exception $e) {
    if ($e->getMessage() == 'NO_CONTENT') {
        if ($default_contenttype == 'text/html') {
            $body_type = 'text/plain';
        }
        else {
            $body_type = 'text/html';
        }
    }
}
try {
    $body_content = $EMail->getBody($body_type);
}
catch (Exception $e) {
    $App->log('Cannot fetch email body: '.$e->getMessage(),1,'printMail');
    $body_content = '<br /><b>Diese Mail kann nicht gedruckt werden</b>';
}

if ($body_type == 'text/html') {
    $body_content = preg_replace('/<html[^>]*>(.*?)<\/html>/is','${1}',$body_content);
    $body_content = preg_replace('/<body[^>]*>(.*?)<\/body>/is','${1}',$body_content);
    $App->assign('HTMLBODY',true);
}

$App->assign('EMPTY',true);
$App->assign('MailBody',$body_content);
$App->assign('EMail',$EMail);

?>

==> benno-web-2.8.0.tgz: srv/benno/bennoweb/htdocs/view/printMail.php <==
<?php
/*
 * Benno MailArchiv
 *
 * Copyright  2008-2012 LWsystems GmbH & Co. KG
 *
 * http://www.lw-systems.de/
 * http://www.benno-mailarchiv.de/
 *
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License version 3
 * as published by the Free Software Foundation.
 *
 * Binary versions of this file provided by LWsystems to you as
 * well as other copyrighted, protected or trademarked materials like
 * logos, graphics, fonts, specific documentations and configurations,
 * cryptographic keys etc. are subject to a license agreement between
 * you and LWsystems.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You can find a copy of the GNU Affero General Public License at
 * this URI:
 * http://www.gnu.org/licenses/agpl-3.0.html
 * If not, write to the Free Software Foundation, Inc., 59 Temple Place,
 * Suite 330, Boston, MA  02111-1307  USA
 */

$default_contenttype = $App->getConfig('DEFAULT_CONTENTYPE','text/html');
try {
    $body_content = $EMail->getBody($default_contenttype);
    $body_type = $default_contenttype;
}
catch (Exception $e) {
    if ($e->getMessage() == 'NO_CONTENT') {
        if ($default_contenttype == 'text/html') {
            $body_type = 'text/plain';
        }
        else {
            $body_type = 'text/html';
        }
    }
}
try {
    $body_content = $EMail->getBody($body_type);
}
catch (Exception $e) {
    $App->log('Cannot fetch email body: '.$e->getMessage(),1,'printMail');
    $body_content = '<br /><b>Diese Mail kann nicht gedruckt werden</b>';
}

if ($body_type == 'text/html') {
    $body_content = preg_replace('/<html[^>]*>(.*?)<\/html>/is','${1}',$body_content);
    $body_content = preg_replace('/<body[^>]*>(.*?)<\/body>/is','${1}',$body_content);
    $App->assign('HTMLBODY',true);
}

$App->assign('EMPTY',true);
$App->assign('MailBody',$body_content);
$App->assign('EMail',$EMail);

?>
